@@ -15,10 +15,22 @@ $api->set_api_config_from_file('/usr/local/etc/dwolla_api.conf');
 # Example 1: Retrieve a list of transactions for the user associated with the
 # provided OAuth token.
 
-my $listings = $api->listings('02-01-2012');
+my $listings = $api->listings();
 
 if (!$listings) {
     print Dumper($api->get_errors());
 } else {
     print Dumper($listings);
 }
+
+# Example #2: Get transaction info by an ID.
+
+my $tid = '0000000';
+
+my $transaction = $api->transaction($tid);
+if (!$transaction) {
+    print Dumper($api->get_errors());
+} else {
+    print Dumper($transaction);
+}
+
